Enum byte_order::Endianness [−][src]
pub enum Endianness {
BE,
LE,
}The two possible endianness operations can be performed with.
pub enum Endianness {
BE,
LE,
}The two possible endianness operations can be performed with.
impl RefUnwindSafe for Endiannessimpl Send for Endiannessimpl Sync for Endiannessimpl Unpin for Endiannessimpl UnwindSafe for Endianness